@@ -1,4 +1,4 @@
-NUM_VERSION = (2013, 2)
+NUM_VERSION = (2013, 3)
 VERSION = ".".join(str(nv) for nv in NUM_VERSION)
 __version__ = VERSION
 
@@ -6,6 +6,8 @@ from pudb.py3compat import raw_input
 
 
 CURRENT_DEBUGGER = []
+
+
 def _get_debugger(**kwargs):
     if not CURRENT_DEBUGGER:
         from pudb.debugger import Debugger
@@ -20,6 +22,7 @@ import signal
 DEFAULT_SIGNAL = signal.SIGINT
 del signal
 
+
 def runscript(mainpyfile, args=None, pre_run="", steal_output=False):
     dbg = _get_debugger(steal_output=steal_output)
 
@@ -53,7 +56,8 @@ def runscript(mainpyfile, args=None, pre_run="", steal_output=False):
             dbg._runscript(mainpyfile)
         except SystemExit:
             se = sys.exc_info()[1]
-            status_msg = "The debuggee exited normally with status code %s.\n\n" % se.code
+            status_msg = "The debuggee exited normally with " \
+                    "status code %s.\n\n" % se.code
         except:
             dbg.post_mortem = True
             dbg.interaction(None, sys.exc_info())
@@ -68,8 +72,8 @@ def runscript(mainpyfile, args=None, pre_run="", steal_output=False):
                     "Would you like to quit PuDB or restart your program?\n"
                     "You may hit 'q' to quit."
                     % status_msg),
-                    urwid.Text("\n\nIf you decide to restart, this command will be run prior to "
-                    "actually restarting:"),
+                    urwid.Text("\n\nIf you decide to restart, this command "
+                    "will be run prior to actually restarting:"),
                     urwid.AttrMap(pre_run_edit, "value")
                     ]),
                 [
@@ -104,15 +108,19 @@ def runscript(mainpyfile, args=None, pre_run="", steal_output=False):
 
     sys.path = prev_sys_path
 
+
 def runstatement(statement, globals=None, locals=None):
     _get_debugger().run(statement, globals, locals)
 
+
 def runeval(expression, globals=None, locals=None):
     return _get_debugger().runeval(expression, globals, locals)
 
+
 def runcall(*args, **kwds):
     return _get_debugger().runcall(*args, **kwds)
 
+
 def set_trace():
     import sys
     dbg = _get_debugger()
@@ -125,6 +133,7 @@ def _interrupt_handler(signum, frame):
     from pudb import _get_debugger
     _get_debugger().set_trace(frame)
 
+
 def set_interrupt_handler(interrupt_signal=DEFAULT_SIGNAL):
     """
     Set up an interrupt handler, to activate PuDB when Python receives the
@@ -153,6 +162,7 @@ def set_interrupt_handler(interrupt_signal=DEFAULT_SIGNAL):
         warn("setting interrupt handler on signal %d failed: %s"
                 % (interrupt_signal, "".join(format_exception(sys.exc_info()))))
 
+
 def post_mortem(tb=None, e_type=None, e_value=None):
     if tb is None:
         import sys
@@ -169,8 +179,6 @@ def post_mortem(tb=None, e_type=None, e_value=None):
     dbg.interaction(tb.tb_frame, exc_info)
 
 
-
-
 def pm():
     import sys
     try:
@@ -183,7 +191,5 @@ def pm():
     post_mortem(tb, e_type, e_value)
 
 
-
-
 if __name__ == "__main__":
     print("You now need to type 'python -m pudb.run'. Sorry.")
